'use strict';
const MarkdownItAttrs = require('markdown-it-attrs');
const MarkdownItContainer = require('markdown-it-container');
const MarkdownItMath = require('markdown-it-math');
const MarkdownItDecorate = require('markdown-it-decorate');
const MarkdownIt = require('metalsmith-markdownit/node_modules/markdown-it');


exports = module.exports = {};

/**
 * Load given markdown-it parser with all the plugins we need
 */
exports.initParser = function (parser) {
    return parser
        .use(MarkdownItAttrs)
        .use(MarkdownItMath)
        .use(MarkdownItDecorate)
        .use(MarkdownItContainer, 'div', {
            render: function (tokens, idx) {
                if (tokens[idx].nesting === 1) {
                    // opening tag

                    const attrs = tokens[idx].info.trim();
                    const classes = [];
                    let id;

                    attrs.split(/\s+/g).forEach((attr) => {
                        if (attr.startsWith('.')) {
                            classes.push(attr.slice(1));
                        } else if (attr.startsWith('#')) {
                            id = attr.slice(1);
                        }
                    });

                    let node = '<div';
                    if (id) {
                        node += ` id="${id}"`;
                    }
                    if (classes.length > 0) {
                        node += ` class="${classes.join(' ')}"`;
                    }
                    node += '>\n';

                    return node;

                } else {
                    // closing tag
                    return '</div>\n';
                }
            }
        });
};

/**
 * A JSTransformers wrapper for our custom markdown-it parser
 * Based on https://github.com/jstransformers/jstransformer-markdown-it/blob/master/index.js
 */
exports.jstransformer = function (str, options) {
    options = options || {};
    let md = MarkdownIt(options);
    md = exports.initParser(md);

    if (options.inline) {
        return md.renderInline(str);
    } else {
        return md.render(str);
    }
};

