'use strict';
const Fs = require('fs');
const GulpUtil = require('gulp-util');
const StripJsonComments = require('strip-json-comments');
const Joi = require('joi');
const Plugins = require('./plugins');
const _ = require('lodash');
const Path = require('path');

exports = module.exports = {};

exports.isDev = false;

// Read and parse a JSON file, possibly with comments, synchronously
exports.readJson = function (path) {
  try {
    return JSON.parse(StripJsonComments(Fs.readFileSync(path, 'utf8')));
  } catch (err) {
    GulpUtil.log('Error parsing json file at ' + GulpUtil.colors.green(path));
    throw err;
  }
};

exports.streamErrorHandler = function (error) {
  if (exports.isDev) {
    // Send error to notification center with Gulp-notify
    Plugins.notify.onError({
      title: "Compile Error",
      icon: Path.join(__dirname, '../images/failed.png')
    }).apply(this, arguments);

    // emit the end event, to properly end the task
    this.emit('end');
  } else {
    console.log(error.toString());
    console.log('Exiting with code 1');
    process.exit(1);
  }
};

exports.errorHandler = function (error) {
  console.log(exports.isDev);
  if (exports.isDev) {
    // Send error to notification center with Gulp-notify
    Plugins.notify.onError({
      title: "Compile Error",
      icon: Path.join(__dirname, '../images/failed.png')
    }).apply(null, arguments);

  } else {
    console.log(error.toString());
    console.log('Exiting with code 1');
    process.exit(1);
  }
};
